pub enum VolasError {
ColumnNotFound(String),
DType(String),
Shape(String),
Index(String),
Value(String),
Parse(String),
}Expand description
Errors raised by the volas core. The Python binding maps each variant to a
typed exception (see volas-python).
Variants
ColumnNotFound(String)
A column name was not found in the frame.
DType(String)
A dtype-incompatible operation (e.g. appending Bool onto F64).
Shape(String)
Mismatched lengths / shapes (e.g. columns of unequal height).
Index(String)
Out-of-range or otherwise invalid index access.
Value(String)
A bad argument value.
Parse(String)
A directive string that could not be tokenized / parsed (a syntax error,
annotated with line / column), as opposed to a Value error
for a well-formed directive with an invalid command / argument.